==> ui-framework-4.7.3-sources.jar: io/intino/alexandria/ui/displays/items/GroupingToolbar1Mold.java <==
package io.intino.alexandria.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class GroupingToolbar1Mold extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, io.intino.alexandria.ui.documentation.Person, UiFrameworkBox> {
	public FirstName1 firstName1;
	public Grotoo_20_9_0689003713 grotoo_20_9_0689003713;
	public GroupingToolbar1Mold.Grotoo_20_9_0689003713. Gender1 gender1;
	public GroupingToolbar1Mold.Grotoo_20_9_0689003713. Age1 age1;

    public GroupingToolbar1Mold(UiFrameworkBox box) {
        super(box);
        id("a_1855829012");
    }

    @Override
	public void init() {
		super.init();
		if (firstName1 == null) firstName1 = register(new FirstName1(box()).<FirstName1>id("a1994776681").owner(GroupingToolbar1Mold.this));
		if (grotoo_20_9_0689003713 == null) grotoo_20_9_0689003713 = register(new Grotoo_20_9_0689003713(box()).<Grotoo_20_9_0689003713>id("a_549387944").owner(GroupingToolbar1Mold.this));
		if (grotoo_20_9_0689003713 != null) gender1 = grotoo_20_9_0689003713.gender1;
		if (grotoo_20_9_0689003713 != null) age1 = grotoo_20_9_0689003713.age1;
	}

	public class FirstName1 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

		public FirstName1(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}
	}

	public class Grotoo_20_9_0689003713 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UiFrameworkBox>  {
		public GroupingToolbar1Mold.Grotoo_20_9_0689003713. Gender1 gender1;
		public GroupingToolbar1Mold.Grotoo_20_9_0689003713. Age1 age1;

		public Grotoo_20_9_0689003713(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (gender1 == null) gender1 = register(new Gender1(box()).<Gender1>id("a_1585155376").owner(GroupingToolbar1Mold.this));
			if (age1 == null) age1 = register(new Age1(box()).<Age1>id("a_1377918510").owner(GroupingToolbar1Mold.this));
		}

		public class Gender1 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Gender1(UiFrameworkBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class Age1 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Age1(UiFrameworkBox box) {
				super(box);
				label("age");
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> ui-framework-4.13.4-sources.jar: io/intino/alexandria/ui/displays/items/GroupingToolbar1Mold.java <==
package io.intino.alexandria.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class GroupingToolbar1Mold extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, io.intino.alexandria.ui.documentation.Person, UiFrameworkBox> {
	public FirstName1 firstName1;
	public _20_9_0689003713 _20_9_0689003713;
	public GroupingToolbar1Mold._20_9_0689003713. Gender1 gender1;
	public GroupingToolbar1Mold._20_9_0689003713. Age1 age1;

    public GroupingToolbar1Mold(UiFrameworkBox box) {
        super(box);
        id("a_1855829012");
    }

    @Override
	public void init() {
		super.init();
		if (firstName1 == null) firstName1 = register(new FirstName1(box()).<FirstName1>id("a1994776681").owner(GroupingToolbar1Mold.this));
		if (_20_9_0689003713 == null) _20_9_0689003713 = register(new _20_9_0689003713(box()).<_20_9_0689003713>id("a10423720").owner(GroupingToolbar1Mold.this));
		if (_20_9_0689003713 != null) gender1 = _20_9_0689003713.gender1;
		if (_20_9_0689003713 != null) age1 = _20_9_0689003713.age1;
	}

	public class FirstName1 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

		public FirstName1(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}
	}

	public class _20_9_0689003713 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UiFrameworkBox>  {
		public GroupingToolbar1Mold._20_9_0689003713. Gender1 gender1;
		public GroupingToolbar1Mold._20_9_0689003713. Age1 age1;

		public _20_9_0689003713(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (gender1 == null) gender1 = register(new Gender1(box()).<Gender1>id("a_1585155376").owner(GroupingToolbar1Mold.this));
			if (age1 == null) age1 = register(new Age1(box()).<Age1>id("a_1377918510").owner(GroupingToolbar1Mold.this));
		}

		public class Gender1 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Gender1(UiFrameworkBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class Age1 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Age1(UiFrameworkBox box) {
				super(box);
				label("age");
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}
